@@ -9,9 +9,8 @@ use std::path::Path;
 
 use crate::core::GenericResult;
 
-pub use restorer::Restorer;
+use restorer::Restorer;
 
-// FIXME(konishchev): Implement
 pub fn restore(backup_path: &Path, restore_dir: &Path) -> GenericResult<bool> {
     Restorer::new(backup_path)?.restore(restore_dir)
-}
+}
\ No newline at end of file
