@@ -21,7 +21,7 @@ use crate::backuping::{self, PathFilter};
 use crate::config::{BackupSpecConfig, BackupConfig, BackupItemConfig};
 use crate::core::{GenericResult, EmptyResult};
 use crate::providers::{ReadProvider, filesystem::Filesystem};
-use crate::restoring::Restorer;
+use crate::restoring;
 use crate::storage::{Backup, Storage};
 use crate::storage::metadata::{Fingerprint, MetadataItem};
 use crate::util::hash::Hash;
@@ -98,11 +98,10 @@ fn backup() -> EmptyResult {
             }, BackupItemConfig {
                 path: other_user_path.to_str().unwrap().to_owned(),
                 filter: PathFilter::default(),
-                before: Some(formatdoc!("
-                    date +%T.%N > {before:?}
-                    cp -a {before:?} {after:?}
-                ", before=before_path, after=after_path)),
-                after: Some(format!("date +%T.%N > {:?}", after_path)),
+                before: Some(format!(
+                    "uuidgen > {before:?} && cp -a {before:?} {after:?}",
+                    before=before_path, after=after_path)),
+                after: Some(format!("uuidgen > {:?}", after_path)),
             }, BackupItemConfig {
                 path: var_path.join("data").to_str().unwrap().to_owned(),
                 filter: PathFilter::default(), before: None, after: None,
@@ -275,11 +274,10 @@ fn backup() -> EmptyResult {
 
     for group in groups {
         for backup in group.backups {
-            info!("Restore #{} pass ({})...", restore_pass, backup.name);
-            let restore_dir = temp_dir.join("restore");
+            info!("Restoring #{} pass ({})...", restore_pass, backup.name);
 
-            let restorer = Restorer::new(Path::new(&backup.path))?;
-            assert!(restorer.restore(&restore_dir)?);
+            let restore_dir = temp_dir.join("restore");
+            assert!(restoring::restore(Path::new(&backup.path), &restore_dir)?);
 
             for file_state in &mutable_files_states[restore_pass] {
                 file_state.restore()?;
@@ -287,11 +285,24 @@ fn backup() -> EmptyResult {
 
             let restored_root_path = get_restore_path(&restore_dir, &root_path);
 
-            let ls_tree_command = "ls -ARl --time-style +%Y.%m.%d-%H:%M:%S";
-            shell(&format!(
-                "set -o pipefail && diff -u <(cd {:?} && {}) <(cd {:?} && {})",
-                root_path, ls_tree_command, restored_root_path, ls_tree_command
-            ))?;
+            shell(&formatdoc!(r#"
+                set -eu
+
+                lstree() {{
+                    local time_style_flag="--time-style"
+
+                    if [[ "$(uname)" = Darwin && "$(which ls)" = /bin/ls ]]; then
+                        time_style_flag="-D"
+                    fi
+
+                    ls -ARl "$time_style_flag" +%Y.%m.%d-%H:%M:%S
+                }}
+
+                expected="$(cd {root_path:?} && lstree)"
+                actual="$(cd {restored_path:?} && lstree)"
+
+                diff -u <(cat <<< "$expected") <(cat <<< "$actual")
+            "#, root_path=root_path, restored_path=restored_root_path))?;
 
             run(["git", "diff", "--no-index", root_path.to_str().unwrap(), restored_root_path.to_str().unwrap()])?;
 
@@ -405,7 +416,7 @@ fn run<C: IntoIterator<Item=A>, A: AsRef<OsStr>>(command: C) -> EmptyResult {
 }
 
 fn shell(command: &str) -> EmptyResult {
-    run(["bash", "-ec", command])
+    run(["bash", "-c", command])
 }
 
 fn get_restore_path(restore_dir: &Path, path: &Path) -> PathBuf {
